Crate specado_core

Crate specado_core 

Re-exports

pub use adapter::AdapterMatchRule;
pub use adapter::AdapterRegistry;
pub use adapter::AdapterSelection;
pub use auth::AuthError;
pub use auth::AuthHandler;
pub use auth::AuthScheme;
pub use circuit_breaker::CircuitBreaker;
pub use error::Error;
pub use error::ProviderErrorKind;
pub use error::Result;
pub use retry::RetryPolicy;
pub use router::PrimaryFallbackRouter;
pub use router::Router;
pub use types::*;

Modules

adapter
auth
circuit_breaker
error
hot_reload
http
retry
router
transformer
types

Structs

ExecuteOptions
Options for steering name-based provider resolution.

Functions

execute
Execute a prompt using a provider identified by name or path.
execute_from_path
Execute a prompt using an explicit provider spec path.
translate