pub struct ProviderCache { /* private fields */ }Expand description
Lightweight cache that will be backed by a file watcher once implemented.
Implementations
Sourceimpl ProviderCache
impl ProviderCache
pub fn new() -> Self
Sourcepub fn load_or_read(&self, provider_path: &Path) -> Result<ProviderSpec>
pub fn load_or_read(&self, provider_path: &Path) -> Result<ProviderSpec>
Read and cache the provider spec, updating the entry if it has changed.