Re-exports
pub use adapter::AdapterMatchRule;pub use adapter::AdapterRegistry;pub use adapter::AdapterSelection;pub use auth::AuthError;pub use auth::AuthHandler;pub use auth::AuthScheme;pub use circuit_breaker::CircuitBreaker;pub use error::Error;pub use error::ProviderErrorKind;pub use error::Result;pub use retry::RetryPolicy;pub use router::PrimaryFallbackRouter;pub use router::Router;pub use types::*;
Modules
Structs
- Execute
Options - Options for steering name-based provider resolution.
Functions
- execute
- Execute a prompt using a provider identified by name or path.
- execute_
from_ path - Execute a prompt using an explicit provider spec path.
- translate